<?php
/**
 * Class to store a result from the routino run
 *
 * PHP version 5.1.0+
 *
 * Copyright (c) 2012, Uwe Steinmann
 * 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  - Neither the name of the The PEAR Group nor the names of its contributors 
 *    may be used to endorse or promote products derived from this software 
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @package   Router_Routino
 * @author    Uwe Steinmann <steinm@php.net>
 * @copyright 2012 Uwe Steinmann
 * @license   http://www.opensource.org/licenses/bsd-license.php New BSD License
 * @version   CVS: $Revision: $
 * @link      http://pear.php.net/package/Router_Routino
 */

/**
 * Class to represent the result from a routino run
 *
 * @package   Router_Routino
 * @author    Uwe Steinmann <steinm@php.net>
 * @copyright 2012 Uwe Steinmann
 * @license   http://www.opensource.org/licenses/bsd-license.php New BSD License
 * @link      http://pear.php.net/package/Router_Routino
 */
class Router_Routino_Result { /* {{{ */

  /**
   * @var array $dataarr list of all waypoints
   * @access public
   */
	public $dataarr;

  /**
   * Constructor
   * 
   * @param string $dir directory containing the result files
   */
	function __construct($dir, $type) { /* {{{ */
		if(!file_exists($dir.'/'.$type.'.txt')) {
			return false;
		}
		if(!$fp = fopen($dir.'/'.$type.'.txt', 'r')) {
			return false;
		}
		for($i=0; $i<6; $i++)
			$tmp = fgets($fp);

		$this->dataarr = array();
		while(!feof($fp)) {
			$tmp = fgetcsv($fp, 200, "\t");
			if(count($tmp) > 1) {
				$data['lat'] = (float) $tmp[0];
				$data['lon'] = (float) $tmp[1];
				$k = explode(' ', trim($tmp[2]));
				$data['secdist'] = (float) $k[0];
				$k = explode(' ', trim($tmp[3]));
				$data['sectime'] = (float) $k[0];
				$k = explode(' ', trim($tmp[4]));
				$data['dist'] = (float) $k[0];
				$k = explode(' ', trim($tmp[5]));
				$data['time'] = (float) $k[0];
				$data['pointtype'] = trim($tmp[6]);
				$data['turn'] = (int) $tmp[7];
				$data['bearing'] = (int) $tmp[8];
				$data['highway'] = trim($tmp[9]);

				$this->dataarr[] = $data;
			}
		}
	
		fclose($fp);
	} /* }}} */

  /**
   * Get overall time and distance calculated from the sections
   * 
   * @param string $dir directory containing the result files
	 * @return array with two elements 'time' and 'distance'
   */
	function getTotals() { /* {{{ */
		if(!$this->dataarr) {
			return false;
		}
		$sumtime = $sumdist = 0.0;
		foreach($this->dataarr as $data) {
			$sumtime += $data['sectime'];
			$sumdist += $data['secdist'];
		}
		return array('time'=>$sumtime, 'distance'=>$sumdist);
	} /* }}} */

} /* }}} */
?>
